# Pure


PureML is the tool that lets you register, version, compare and stage models without the hassle of complex software. The core of PureML is the seamless collaboration across the team. 


# Documentation

See [PureML documentation](https://docs.pureml.com)



# Installation

## Get prerequisites
* python versions `^3.8.0` are supported

## Install package

```bash
pip install pureml
```


# Getting Help
If you get stuck, don't worry we are here to help.

- [PureML App](https://app.pureml.com)
- [PureML Discord](https://discord.gg/xNUHt9yguJ)




